Index: pdf/out_of_process_instance.cc |
diff --git a/pdf/out_of_process_instance.cc b/pdf/out_of_process_instance.cc |
index fd69a5aadc3d3e216d04f3fd35f3c25c2ce5253e..7dd41e5f59bdfd1a0c488eaf8ab2f6b2b50dae0f 100644 |
--- a/pdf/out_of_process_instance.cc |
+++ b/pdf/out_of_process_instance.cc |
@@ -347,8 +347,9 @@ bool OutOfProcessInstance::Init(uint32_t argc, |
} |
} |
- // Allow the plugin to handle find requests. |
- SetPluginToHandleFindRequests(); |
+ // Only allow the plugin to handle find requests if it is full frame. |
+ if (full_) |
+ SetPluginToHandleFindRequests(); |
text_input_ = base::MakeUnique<pp::TextInput_Dev>(this); |